DefaultPathJoinStrategy class

Returns an array of path segments.

Path segments of otherUri is returned if otherUri has host else returns path segments of both currentUri and otherUri where currentUri is placed first.

Implemented types

Constructors

DefaultPathJoinStrategy(Uri otherUri, Uri currentUri)
const

Properties

currentUri Uri
finalinherited
hashCode int
The hash code for this object.
no setterinherited
otherUri Uri
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve() Iterable<String>
Returns a path segment as Iterable<String> by resolving (or merging) otherUri and currentUri. This is used in the RequestClient where otherUri is inherited from wrapped (or child) Clients.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited